@@ -9,6 +9,7 @@ class Stenciller::Plugin::ToHtmlPreBlock using Moose with Stenciller::Transforme
     use HTML::Entities 'encode_entities';
 
     method transform {
+
         my @out = ($self->stenciller->all_header_lines);
 
         STENCIL:
@@ -21,19 +22,19 @@ class Stenciller::Plugin::ToHtmlPreBlock using Moose with Stenciller::Transforme
                          $self->normal($stencil->all_after_output);
 
         }
-        return join '' => @out;
+        return join "\n" => @out;
     }
 
     method normal(@lines) {
         return () if !scalar @lines;
-        return join "\n" => '<p>', @lines, '</p>';
+        return join '' => ('<p>', join ("\n" => @lines), '</p>');
     }
 
     method pre(@lines) {
         return () if !scalar @lines;
 
         my @encoded_lines = map {  encode_entities($_) } @lines;
-        return  join "\n" => '<pre>', @encoded_lines, '</pre>';
+        return join '' => ('<pre>', join ("\n" =>  @encoded_lines), '</pre>');
     }
 }
 
@@ -51,7 +52,7 @@ Stenciller::Plugin::ToHtmlPreBlock - A plugin that transforms to html
 
 =head1 VERSION
 
-Version 0.1005, released 2015-01-16.
+Version 0.1100, released 2015-01-16.
 
 =head1 SYNOPSIS
 
