@@ -7,7 +7,7 @@ use Stenciller::Standard;
 class Stenciller::Plugin::ToUnparsedText using Moose with Stenciller::Transformer {
 
     method transform {
-        my @out = ($self->stenciller->all_header_lines);
+        my @out = $self->stenciller->all_header_lines;
 
         STENCIL:
         foreach my $stencil ($self->stenciller->all_stencils) {
@@ -35,7 +35,7 @@ Stenciller::Plugin::ToUnparsedText - A plugin that doesn't transforme the text t
 
 =head1 VERSION
 
-Version 0.1005, released 2015-01-16.
+Version 0.1100, released 2015-01-16.
 
 =head1 SYNOPSIS
 
